@@ -27,10 +27,15 @@ Utilities for documenting functions, classes and methods
 #  MA 02110-1301, USA.
 #
 
+# stdlib
 import builtins
+from textwrap import dedent
+from typing import Any, Callable, Optional, Sequence, Type, TypeVar, Union
+
+F = TypeVar('F', bound=Callable[..., Any])
 
 
-def deindent_string(string):
+def deindent_string(string: str) -> str:
 	"""
 	Removes all indentation from the given string
 
@@ -40,29 +45,27 @@ def deindent_string(string):
 	:return: The string without indentation
 	:rtype: str
 	"""
-	
+
 	split_string = string.split("\n")
 	deindented_string = [line.lstrip("\t ") for line in split_string]
 	return "\n".join(deindented_string)
 
 
 # Functions that do the work
-def document_object_from_another(target, original):
+def document_object_from_another(target: Union[Type, Callable], original: Union[Type, Callable]):
 	"""
 	Sets the docstring of the ``target`` function to that of the ``original`` function.
 
 	This may be useful for subclasses or wrappers that use the same arguments.
 
 	:param target: The object to set the docstring for
-	:type target: any
 	:param original: The object to copy the docstring from
-	:type original: any
 	"""
-	
+
 	target.__doc__ = original.__doc__
 
 
-def append_doctring_from_another(target, original):
+def append_doctring_from_another(target: Union[Type, Callable], original: Union[Type, Callable]):
 	"""
 	Sets the docstring of the ``target`` function to that of the ``original`` function.
 
@@ -73,18 +76,23 @@ def append_doctring_from_another(target, original):
 	Bear this in mind if additional indentation is used in the docstring.
 
 	:param target: The object to append the docstring to
-	:type target: any
 	:param original: The object to copy the docstring from
-	:type original: any
 	"""
-	
-	deindented_target_doc = deindent_string(target.__doc__)
-	deindented_original_doc = deindent_string(original.__doc__)
-	
-	target.__doc__ = deindented_target_doc + "\n" + deindented_original_doc
+
+	target_doc = target.__doc__
+	original_doc = original.__doc__
+
+	if isinstance(original_doc, str) and isinstance(target_doc, str):
+		deindented_target_doc = dedent(target_doc)
+		deindented_original_doc = dedent(original_doc)
+
+		target.__doc__ = deindented_target_doc + "\n" + deindented_original_doc
+
+	elif not isinstance(target_doc, str) and isinstance(original_doc, str):
+		target.__doc__ = dedent(original_doc)
 
 
-def make_sphinx_links(input_string, builtins_list=None):
+def make_sphinx_links(input_string: str, builtins_list: Optional[Sequence[str]] = None) -> str:
 	r"""
 	Make proper sphinx links out of double-backticked strings in docstring.
 
@@ -102,36 +110,36 @@ def make_sphinx_links(input_string, builtins_list=None):
 	:return: processed string with links
 	:rtype: str
 	"""
-	
+
 	if builtins_list is None:
 		builtins_list = dir(builtins)
-	
+
 	working_string = f"{input_string}"
-	
+
 	for builtin in {x for x in builtins_list if not x.startswith("__") and x != "None"}:
 		working_string = working_string.replace(f"``{builtin}``", f":class:`~python:{builtin}`")
-	
+
 	return working_string
 
 
 # Decorators that call the above functions
-def is_documented_by(original):
+def is_documented_by(original: F) -> Callable:
 	"""
-	Sets the docstring of the ``target`` function to that of the ``original`` function.
+	Decorator to set the docstring of the ``target`` function to that of the ``original`` function.
 
 	This may be useful for subclasses or wrappers that use the same arguments.
 	"""
-	
-	def wrapper(target):
+
+	def wrapper(target: F) -> F:
 		document_object_from_another(target, original)
 		return target
-	
+
 	return wrapper
 
 
-def append_docstring_from(original):
+def append_docstring_from(original: F) -> Callable:
 	"""
-	Appends the docstring from the ``original`` function to the ``target`` function.
+	Decorator to appends the docstring from the ``original`` function to the ``target`` function.
 
 	This may be useful for subclasses or wrappers that use the same arguments.
 
@@ -139,26 +147,30 @@ def append_docstring_from(original):
 	ensure consistent indentation between the two docstrings.
 	Bear this in mind if additional indentation is used in the docstring.
 	"""
-	
-	def wrapper(target):
+
+	def wrapper(target: F) -> F:
 		append_doctring_from_another(target, original)
 		return target
-	
+
 	return wrapper
 
 
-def sphinxify_docstring():
+def sphinxify_docstring() -> Callable:
 	r"""
-	Make proper sphinx links out of double-backticked strings in docstring.
+	Decorator to make proper sphinx links out of double-backticked strings in the docstring.
 
 	i.e. \`\`str\`\` becomes \:class\:\`~python:str\`
-	
+
 	Make sure to have `'python': ('https://docs.python.org/3/', None),` in the
 	`intersphinx_mapping` dict of your conf.py for sphinx.
 	"""
-	
-	def wrapper(target):
-		target.__doc__ = make_sphinx_links(target.__doc__)
+
+	def wrapper(target: F) -> F:
+		target_doc = target.__doc__
+
+		if target_doc:
+			target.__doc__ = make_sphinx_links(target_doc)
+
 		return target
-	
+
 	return wrapper
